@@ -2,7 +2,7 @@
 ASGI App using dataclasses module for request/response objects
 """
 
-__version__ = '0.27.2'
+__version__ = '0.28.0'
 
 from apidaora.app import appdaora
 from apidaora.bodies import GZipFactory
@@ -19,7 +19,9 @@ from apidaora.middlewares import (
 from apidaora.request import Request
 from apidaora.responses import (
     Response,
+    css,
     html,
+    javascript,
     json,
     no_content,
     not_found,
@@ -48,4 +50,6 @@ __all__ = [
     'ClassController',
     'BackgroundTaskMiddleware',
     'RoutedControllerTypeHint',
+    'css',
+    'javascript',
 ]
